==> vue-pro-4.1.4.tgz: package/src/components/props.ts <==
const Shape = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return [
      'rounded',
      'rounded-top',
      'rounded-end',
      'rounded-bottom',
      'rounded-start',
      'rounded-circle',
      'rounded-pill',
      'rounded-0',
      'rounded-1',
      'rounded-2',
      'rounded-3',
    ].includes(value)
  },
}
const Align = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return ['', 'left', 'center', 'right'].includes(value)
  },
}
const Color = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return [
      'primary',
      'secondary',
      'success',
      'danger',
      'warning',
      'info',
      'dark',
      'light',
      'link',
      'transparent',
      'primary-gradient',
      'secondary-gradient',
      'success-gradient',
      'danger-gradient',
      'warning-gradient',
      'info-gradient',
      'dark-gradient',
      'light-gradient',
    ].includes(value)
  },
}
const TextColor = {
  type: String,
  validator: (value: string): boolean => {
    return [
      'primary',
      'secondary',
      'success',
      'danger',
      'warning',
      'info',
      'dark',
      'light',
      'white',
      'muted',
      'high-emphasis',
      'medium-emphasis',
      'disabled',
      'high-emphasis-inverse',
      'medium-emphasis-inverse',
      'disabled-inverse',
    ].includes(value)
  },
}
const Breakpoint = {
  validator: (value: boolean | number): boolean => {
    if (typeof value == 'boolean' || typeof value == 'number') {
      return true
    } else {
      return false
    }
  },
}

export { Align, Breakpoint, Color, Shape, TextColor }

==> vue-pro-4.10.2.tgz: package/src/components/props.ts <==
export const Shape = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return [
      'rounded',
      'rounded-top',
      'rounded-end',
      'rounded-bottom',
      'rounded-start',
      'rounded-circle',
      'rounded-pill',
      'rounded-0',
      'rounded-1',
      'rounded-2',
      'rounded-3',
    ].includes(value)
  },
}

export const Align = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return ['', 'left', 'center', 'right'].includes(value)
  },
}

export const Color = {
  type: String,
  validator: (value: string): boolean => {
    // The value must match one of these strings
    return [
      'primary',
      'secondary',
      'success',
      'danger',
      'warning',
      'info',
      'dark',
      'light',
      'link',
      'transparent',
      'primary-gradient',
      'secondary-gradient',
      'success-gradient',
      'danger-gradient',
      'warning-gradient',
      'info-gradient',
      'dark-gradient',
      'light-gradient',
    ].includes(value)
  },
}

export const TextColor = {
  type: String,
  validator: (value: string): boolean => {
    return [
      'primary',
      'secondary',
      'success',
      'danger',
      'warning',
      'info',
      'dark',
      'light',
      'white',
      'muted',
      'high-emphasis',
      'medium-emphasis',
      'disabled',
      'high-emphasis-inverse',
      'medium-emphasis-inverse',
      'disabled-inverse',
    ].includes(value)
  },
}

export const Breakpoint = {
  validator: (value: boolean | number): boolean => {
    return typeof value == 'boolean' || typeof value == 'number' ? true : false
  },
}
